==> FilterPype-0.3.4.zip: FilterPype-0.3.4/filterpype/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) Flight Data Services Ltd
# http://www.flightdataservices.com
# See the file "LICENSE" for the full license governing this code.

__packagename__ = 'FilterPype'
__version__ = '0.3.4'
__author__ = 'Flight Data Services Ltd'
__author_email__ = 'developers@flightdataservices.com'
__maintainer__ = 'Flight Data Services Ltd'
__maintainer_email__ = 'developers@flightdataservices.com'
__url__= 'http://www.filterpype.org/'
__description__ ='FilterPype is a process-flow pipes-and-filters Python \
framework.'
__download_url__= 'http://www.filterpype.org/'
__classifiers__ = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'Intended Audience :: Science/Research',
    'License :: OSI Approved',
    'Programming Language :: Python :: 2.5',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: Implementation :: CPython',
    'Operating System :: OS Independent',
    'Topic :: Scientific/Engineering :: Information Analysis',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Topic :: Software Development :: Libraries :: Python Modules',
    ]
__platforms__= ['OS Independent']
__license__ = 'Open Software License (OSL-3.0)'
__keywords__= ['process', 'flow', 'pipes', 'filters', 'framework']

################################################################################
# vim:et:ft=python:nowrap:sts=4:sw=4:ts=4

==> FilterPype-0.3.5.zip: FilterPype-0.3.5/filterpype/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) Flight Data Services Ltd
# http://www.flightdataservices.com
# See the file "LICENSE" for the full license governing this code.

__packagename__ = 'FilterPype'
__version__ = '0.3.5'
__author__ = 'Flight Data Services Ltd'
__author_email__ = 'developers@flightdataservices.com'
__maintainer__ = 'Flight Data Services Ltd'
__maintainer_email__ = 'developers@flightdataservices.com'
__url__= 'http://www.filterpype.org/'
__description__ ='FilterPype is a process-flow pipes-and-filters Python framework.'
__download_url__= 'http://www.filterpype.org/'
__classifiers__ = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'Intended Audience :: Science/Research',
    'License :: OSI Approved',
    'Programming Language :: Python :: 2.5',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: Implementation :: CPython',
    'Operating System :: OS Independent',
    'Topic :: Scientific/Engineering :: Information Analysis',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Topic :: Software Development :: Libraries :: Python Modules',
    ]
__platforms__= ['OS Independent']
__license__ = 'Open Software License (OSL-3.0)'
__keywords__= ['process', 'flow', 'pipes', 'filters', 'framework']

################################################################################
# vim:et:ft=python:nowrap:sts=4:sw=4:ts=4
